==> certmanager-model-v1alpha3-6.7.2-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/ACMEChallengeSolverDNS01Builder.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ACMEChallengeSolverDNS01Builder extends ACMEChallengeSolverDNS01FluentImpl<ACMEChallengeSolverDNS01Builder> implements VisitableBuilder<ACMEChallengeSolverDNS01,ACMEChallengeSolverDNS01Builder>{
  public ACMEChallengeSolverDNS01Builder() {
    this(false);
  }
  public ACMEChallengeSolverDNS01Builder(Boolean validationEnabled) {
    this(new ACMEChallengeSolverDNS01(), validationEnabled);
  }
  public ACMEChallengeSolverDNS01Builder(ACMEChallengeSolverDNS01Fluent<?> fluent) {
    this(fluent, false);
  }
  public ACMEChallengeSolverDNS01Builder(ACMEChallengeSolverDNS01Fluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ACMEChallengeSolverDNS01(), validationEnabled);
  }
  public ACMEChallengeSolverDNS01Builder(ACMEChallengeSolverDNS01Fluent<?> fluent,ACMEChallengeSolverDNS01 instance) {
    this(fluent, instance, false);
  }
  public ACMEChallengeSolverDNS01Builder(ACMEChallengeSolverDNS01Fluent<?> fluent,ACMEChallengeSolverDNS01 instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withAcmedns(instance.getAcmedns());
      fluent.withAkamai(instance.getAkamai());
      fluent.withAzuredns(instance.getAzuredns());
      fluent.withClouddns(instance.getClouddns());
      fluent.withCloudflare(instance.getCloudflare());
      fluent.withCnameStrategy(instance.getCnameStrategy());
      fluent.withDigitalocean(instance.getDigitalocean());
      fluent.withRfc2136(instance.getRfc2136());
      fluent.withRoute53(instance.getRoute53());
      fluent.withWebhook(instance.getWebhook());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ACMEChallengeSolverDNS01Builder(ACMEChallengeSolverDNS01 instance) {
    this(instance,false);
  }
  public ACMEChallengeSolverDNS01Builder(ACMEChallengeSolverDNS01 instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withAcmedns(instance.getAcmedns());
      this.withAkamai(instance.getAkamai());
      this.withAzuredns(instance.getAzuredns());
      this.withClouddns(instance.getClouddns());
      this.withCloudflare(instance.getCloudflare());
      this.withCnameStrategy(instance.getCnameStrategy());
      this.withDigitalocean(instance.getDigitalocean());
      this.withRfc2136(instance.getRfc2136());
      this.withRoute53(instance.getRoute53());
      this.withWebhook(instance.getWebhook());
    }
    this.validationEnabled = validationEnabled; 
  }
  ACMEChallengeSolverDNS01Fluent<?> fluent;
  Boolean validationEnabled;
  public ACMEChallengeSolverDNS01 build() {
    ACMEChallengeSolverDNS01 buildable = new ACMEChallengeSolverDNS01(fluent.getAcmedns(),fluent.getAkamai(),fluent.getAzuredns(),fluent.getClouddns(),fluent.getCloudflare(),fluent.getCnameStrategy(),fluent.getDigitalocean(),fluent.getRfc2136(),fluent.getRoute53(),fluent.getWebhook());
    return buildable;
  }
  
}

==> certmanager-model-v1alpha3-6.8.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/ACMEChallengeSolverDNS01Builder.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ACMEChallengeSolverDNS01Builder extends ACMEChallengeSolverDNS01Fluent<ACMEChallengeSolverDNS01Builder> implements VisitableBuilder<ACMEChallengeSolverDNS01,ACMEChallengeSolverDNS01Builder>{
  public ACMEChallengeSolverDNS01Builder() {
    this(false);
  }
  public ACMEChallengeSolverDNS01Builder(Boolean validationEnabled) {
    this(new ACMEChallengeSolverDNS01(), validationEnabled);
  }
  public ACMEChallengeSolverDNS01Builder(ACMEChallengeSolverDNS01Fluent<?> fluent) {
    this(fluent, false);
  }
  public ACMEChallengeSolverDNS01Builder(ACMEChallengeSolverDNS01Fluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ACMEChallengeSolverDNS01(), validationEnabled);
  }
  public ACMEChallengeSolverDNS01Builder(ACMEChallengeSolverDNS01Fluent<?> fluent,ACMEChallengeSolverDNS01 instance) {
    this(fluent, instance, false);
  }
  public ACMEChallengeSolverDNS01Builder(ACMEChallengeSolverDNS01Fluent<?> fluent,ACMEChallengeSolverDNS01 instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ACMEChallengeSolverDNS01());

    if (instance != null) {
      fluent.withAcmedns(instance.getAcmedns());
      fluent.withAkamai(instance.getAkamai());
      fluent.withAzuredns(instance.getAzuredns());
      fluent.withClouddns(instance.getClouddns());
      fluent.withCloudflare(instance.getCloudflare());
      fluent.withCnameStrategy(instance.getCnameStrategy());
      fluent.withDigitalocean(instance.getDigitalocean());
      fluent.withRfc2136(instance.getRfc2136());
      fluent.withRoute53(instance.getRoute53());
      fluent.withWebhook(instance.getWebhook());
      fluent.withAcmedns(instance.getAcmedns());
      fluent.withAkamai(instance.getAkamai());
      fluent.withAzuredns(instance.getAzuredns());
      fluent.withClouddns(instance.getClouddns());
      fluent.withCloudflare(instance.getCloudflare());
      fluent.withCnameStrategy(instance.getCnameStrategy());
      fluent.withDigitalocean(instance.getDigitalocean());
      fluent.withRfc2136(instance.getRfc2136());
      fluent.withRoute53(instance.getRoute53());
      fluent.withWebhook(instance.getWebhook());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ACMEChallengeSolverDNS01Builder(ACMEChallengeSolverDNS01 instance) {
    this(instance,false);
  }
  public ACMEChallengeSolverDNS01Builder(ACMEChallengeSolverDNS01 instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ACMEChallengeSolverDNS01());

    if (instance != null) {
      this.withAcmedns(instance.getAcmedns());
      this.withAkamai(instance.getAkamai());
      this.withAzuredns(instance.getAzuredns());
      this.withClouddns(instance.getClouddns());
      this.withCloudflare(instance.getCloudflare());
      this.withCnameStrategy(instance.getCnameStrategy());
      this.withDigitalocean(instance.getDigitalocean());
      this.withRfc2136(instance.getRfc2136());
      this.withRoute53(instance.getRoute53());
      this.withWebhook(instance.getWebhook());
      this.withAcmedns(instance.getAcmedns());
      this.withAkamai(instance.getAkamai());
      this.withAzuredns(instance.getAzuredns());
      this.withClouddns(instance.getClouddns());
      this.withCloudflare(instance.getCloudflare());
      this.withCnameStrategy(instance.getCnameStrategy());
      this.withDigitalocean(instance.getDigitalocean());
      this.withRfc2136(instance.getRfc2136());
      this.withRoute53(instance.getRoute53());
      this.withWebhook(instance.getWebhook());
    }
    this.validationEnabled = validationEnabled; 
  }
  ACMEChallengeSolverDNS01Fluent<?> fluent;
  Boolean validationEnabled;
  public ACMEChallengeSolverDNS01 build() {
    ACMEChallengeSolverDNS01 buildable = new ACMEChallengeSolverDNS01(fluent.buildAcmedns(),fluent.buildAkamai(),fluent.buildAzuredns(),fluent.buildClouddns(),fluent.buildCloudflare(),fluent.getCnameStrategy(),fluent.buildDigitalocean(),fluent.buildRfc2136(),fluent.buildRoute53(),fluent.buildWebhook());
    return buildable;
  }
  
}
